@@ -338,7 +338,10 @@ class FieldRenderer(BaseRenderer):
         if enclosing_div:
             for label in enclosing_div.find_all("label"):
                 label.attrs["class"] = label.attrs.get("class", []) + ["form-check-label"]
-                label.input.attrs["class"] = label.input.attrs.get("class", []) + ["form-check-input"]
+                try:
+                    label.input.attrs["class"] = label.input.attrs.get("class", []) + ["form-check-input"]
+                except AttributeError:
+                    pass
         return str(soup)
 
     def add_checkbox_label(self, html):
@@ -356,6 +359,11 @@ class FieldRenderer(BaseRenderer):
         html = html.replace("</select>", "</select>" + div2)
         return '<div class="row bootstrap4-multi-input">{html}</div>'.format(html=html)
 
+    def fix_file_input_label(self, html):
+        if self.layout != "horizontal":
+            html = "<br>" + html
+        return html
+
     def post_widget_render(self, html):
         if isinstance(self.widget, RadioSelect):
             html = self.list_to_class(html, "radio radio-success")
@@ -365,6 +373,8 @@ class FieldRenderer(BaseRenderer):
             html = self.fix_date_select_input(html)
         elif isinstance(self.widget, CheckboxInput):
             html = self.add_checkbox_label(html)
+        elif isinstance(self.widget, FileInput):
+            html = self.fix_file_input_label(html)
         return html
 
     def wrap_widget(self, html):
